==> treuchtlingen-foxde-config_1.0.31.orig.tar.gz: treuchtlingen-foxde-config-1.0.31/firefox-external/etc/skel/.mozilla/firefox/firefox.default/user.js <==
//
/******************************************************************************
 * user.js                                                                    *
 ******************************************************************************/

// Customize

//user_pref("extensions.activeThemeID", "{377acd8b-85d6-407b-8ecc-245502314676}");
//user_pref("browser.newtabpage.pinned", "[{\"url\":\"https://duckduckgo.com\",\"label\":\"@duckduckgo\",\"searchTopSite\":true}]");
//user_pref("browser.newtabpage.pinned", "[{\"url\":\"https://www.treuchtlingen.de/\",\"label\":\"Stadt Treuchtlingen\"},{\"url\":\"https://www.treuchtlingen.de\",\"label\":\"@trechtlingen\",\"searchTopSite\":true}]");

user_pref("browser.newtabpage.pinned", "[
{\"url\":\"https://www.treuchtlingen.de/\",\"label\":\"Stadt Treuchtlingen\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://meet.treuchtlingen.de\",\"label\":\"Treuchtlingen Meet 1\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://meet2.treuchtlingen.de\",\"label\":\"Treuchtlingen Meet 2\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://duckduckgo.com\",\"label\":\"duckduckgo\"}]");

// New Tab Page
user_pref("datareporting.policy.firstRunURL", "https://www.freistaat.bayern/dokumente/behoerde/01886659481");
user_pref("browser.newtabpage.directory.source", "");
user_pref("browser.topsites.useRemoteSetting", false);
user_pref("browser.newtabpage.activity-stream.default.sites", "");
user_pref("browser.newtabpage.activity-stream.improvesearch.topSiteSearchShortcuts.havePinned", "duckduckgo");
user_pref("browser.newtabpage.activity-stream.tippyTop.service.endpoint", "");
user_pref("browser.newtabpage.activity-stream.topSitesRows", 4);
user_pref("browser.newtabpage.activity-stream.feeds.telemetry", false);
user_pref("browser.newtabpage.activity-stream.telemetry", false);
user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
user_pref("browser.newtabpage.activity-stream.feeds.section.topstories", false);
user_pref("browser.newtabpage.activity-stream.section.highlights.includePocket", false);
user_pref("browser.newtabpage.activity-stream.showSponsored", false);
user_pref("browser.newtabpage.activity-stream.feeds.discoverystreamfeed", false);
user_pref("browser.newtabpage.activity-stream.showSponsoredTopSites", false);
user_pref("browser.newtabpage.activity-stream.default.sites", "");
user_pref("browser.newtabpage.activity-stream.showSearch", false);


// Performance Settings
// Hardware
user_pref("dom.ipc.processCount",0);
user_pref("dom.ipc.processCount.web",0);
user_pref("accessibility.force_disabled",0);

// Disable Smooth Scrolling
user_pref("general.smoothScroll", false);

// Disable WebGL Scrolling
user_pref("webgl.disabled", false);

// Disable Hardware Rendering
//user_pref("gfx.xrender.enabled", true);

// Use LANG environment variable to choose locale
user_pref("intl.locale.requested", "de");
user_pref("intl.accept_languages", "de");

// Disable default browser checking.
user_pref("browser.shell.checkDefaultBrowser", false);

// Disable openh264.
//user_pref("media.gmp-gmpopenh264.enabled", false);

// Default to classic view for about:newtab
user_pref("browser.newtabpage.enhanced", false, sticky);

//Security
// disable "Pocket" (third party "save for later" service) & remove urls for good measure
user_pref("browser.pocket.enabled", false);
user_pref("extensions.pocket.enabled", false);
user_pref("browser.pocket.api", "");
user_pref("browser.pocket.site", "");
user_pref("browser.pocket.oAuthConsumerKey", "");

// deny cloud upload of screenshots
user_pref("extensions.screenshots.upload-disabled", true);

// Hide "Know your Rights"
user_pref("browser.rights.3.shown", true);

// Hide "What is New"
user_pref("browser.startup.homepage_override.mstone","ignore");

// Switch off Video Autoplay
user_pref("media.autoplay.enabled","false");

// Switch off PDFJS
user_pref("pdfjs.disabled", true);

// Soft Settings
user_pref("network.trr.mode", 5);
// Disable health report upload
user_pref("datareporting.healthreport.uploadEnabled", false);
// PREF: control how tabs are loaded when a session is restored.
// true=Tabs are not loaded until they are selected (default)
// false=Tabs begin to load immediately.
user_pref("browser.sessionstore.restore_on_demand", true); // default
user_pref("browser.sessionstore.restore_pinned_tabs_on_demand", true);
user_pref("browser.sessionstore.restore_tabs_lazily", true); // default

// Privacy
// PREF: Disable Extension Recommendations (CFR: "Contextual Feature Recommender")
// https://support.mozilla.org/en-US/kb/extension-recommendations
user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.features", false);
user_pref("extensions.getAddons.showPane", false);

==> treuchtlingen-foxde-config_1.6.2.orig.tar.gz: treuchtlingen-foxde-config-1.6.2/firefox-external/etc/skel/.mozilla/firefox/firefox.default/user.js <==
//
/******************************************************************************
 * user.js                                                                    *
 ******************************************************************************/

// Customize

//user_pref("extensions.activeThemeID", "{377acd8b-85d6-407b-8ecc-245502314676}");
//user_pref("browser.newtabpage.pinned", "[{\"url\":\"https://duckduckgo.com\",\"label\":\"@duckduckgo\",\"searchTopSite\":true}]");
//user_pref("browser.newtabpage.pinned", "[{\"url\":\"https://www.treuchtlingen.de/\",\"label\":\"Stadt Treuchtlingen\"},{\"url\":\"https://www.treuchtlingen.de\",\"label\":\"@trechtlingen\",\"searchTopSite\":true}]");

user_pref("browser.newtabpage.pinned", "[
{\"url\":\"https://www.treuchtlingen.de/\",\"label\":\"Stadt Treuchtlingen\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://meet.treuchtlingen.de\",\"label\":\"Treuchtlingen Meet\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://cloud.treuchtlingen.de\",\"label\":\"Treuchtlingen Nextcloud\",\"baseDomain\":\"treuchtlingen.de\"},
{\"url\":\"https://duckduckgo.com\",\"label\":\"duckduckgo\"}]");

// New Tab Page
user_pref("datareporting.policy.firstRunURL", "https://www.freistaat.bayern/dokumente/behoerde/01886659481");
user_pref("browser.newtabpage.directory.source", "");
user_pref("browser.topsites.useRemoteSetting", false);
user_pref("browser.newtabpage.activity-stream.default.sites", "");
user_pref("browser.newtabpage.activity-stream.improvesearch.topSiteSearchShortcuts.havePinned", "duckduckgo");
user_pref("browser.newtabpage.activity-stream.tippyTop.service.endpoint", "");
user_pref("browser.newtabpage.activity-stream.topSitesRows", 4);
user_pref("browser.newtabpage.activity-stream.feeds.telemetry", false);
user_pref("browser.newtabpage.activity-stream.telemetry", false);
user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
user_pref("browser.newtabpage.activity-stream.feeds.section.topstories", false);
user_pref("browser.newtabpage.activity-stream.section.highlights.includePocket", false);
user_pref("browser.newtabpage.activity-stream.showSponsored", false);
user_pref("browser.newtabpage.activity-stream.feeds.discoverystreamfeed", false);
user_pref("browser.newtabpage.activity-stream.showSponsoredTopSites", false);
user_pref("browser.newtabpage.activity-stream.default.sites", "");
user_pref("browser.newtabpage.activity-stream.showSearch", false);


// Performance Settings
// Hardware
user_pref("dom.ipc.processCount",0);
user_pref("dom.ipc.processCount.web",0);
user_pref("accessibility.force_disabled",0);

// Disable Smooth Scrolling
user_pref("general.smoothScroll", false);

// Disable WebGL Scrolling
user_pref("webgl.disabled", false);

// Disable Hardware Rendering
//user_pref("gfx.xrender.enabled", true);

// Use LANG environment variable to choose locale
user_pref("intl.locale.requested", "de");
user_pref("intl.accept_languages", "de");

// Disable default browser checking.
user_pref("browser.shell.checkDefaultBrowser", false);

// Disable openh264.
//user_pref("media.gmp-gmpopenh264.enabled", false);

// Default to classic view for about:newtab
user_pref("browser.newtabpage.enhanced", false, sticky);

//Security
// disable "Pocket" (third party "save for later" service) & remove urls for good measure
user_pref("browser.pocket.enabled", false);
user_pref("extensions.pocket.enabled", false);
user_pref("browser.pocket.api", "");
user_pref("browser.pocket.site", "");
user_pref("browser.pocket.oAuthConsumerKey", "");

// deny cloud upload of screenshots
user_pref("extensions.screenshots.upload-disabled", true);

// Hide "Know your Rights"
user_pref("browser.rights.3.shown", true);

// Hide "What is New"
user_pref("browser.startup.homepage_override.mstone","ignore");

// Switch off Video Autoplay
user_pref("media.autoplay.enabled","false");

// Switch off PDFJS
//user_pref("pdfjs.disabled", true);

// Soft Settings
user_pref("network.trr.mode", 5);
// Disable health report upload
user_pref("datareporting.healthreport.uploadEnabled", false);
// PREF: control how tabs are loaded when a session is restored.
// true=Tabs are not loaded until they are selected (default)
// false=Tabs begin to load immediately.
user_pref("browser.sessionstore.restore_on_demand", true); // default
user_pref("browser.sessionstore.restore_pinned_tabs_on_demand", true);
user_pref("browser.sessionstore.restore_tabs_lazily", true); // default

// Privacy
// PREF: Disable Extension Recommendations (CFR: "Contextual Feature Recommender")
// https://support.mozilla.org/en-US/kb/extension-recommendations
user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.features", false);
user_pref("extensions.getAddons.showPane", false);
